as.data.frame.MDgof_power: Convert an MDgof power result to a data frame

View source: R/gof_power.R

as.data.frame.MDgof_powerR Documentation

Convert an MDgof power result to a data frame

Description

Convert an MDgof power result to a data frame

Usage

## S3 method for class 'MDgof_power'
as.data.frame(x, row.names = NULL, optional = FALSE, ...)

Arguments

x

An object of class "MDgof_power".

row.names

Ignored.

optional

Ignored.

...

Currently unused.

Value

A data frame with columns for the alternative parameter, method, power estimate, Monte Carlo standard error, and Wilson confidence limits.


MDgof documentation built on Sept. 23, 2026, 5:08 p.m.