| as.data.frame.MDgof_power | R Documentation |
Convert an MDgof power result to a data frame
## S3 method for class 'MDgof_power'
as.data.frame(x, row.names = NULL, optional = FALSE, ...)
x |
An object of class |
row.names |
Ignored. |
optional |
Ignored. |
... |
Currently unused. |
A data frame with columns for the alternative parameter, method, power estimate, Monte Carlo standard error, and Wilson confidence limits.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.